if(typeof Trustindex_Collector_JS_loaded == 'undefined')
{
	var Trustindex_Collector_JS_loaded = {};
}

Trustindex_Collector_JS_loaded.common = true;

jQuery.fn.ajaxSubmit = function(callback, custom_data) {
	let form = jQuery(this);
	let data = form.serializeArray();

	if(custom_data)
	{
		data.forEach((d) => {
			if(typeof custom_data[ d.name ] != 'undefined')
			{
				d.value = custom_data[ d.name ];
			}
		});
	}

	jQuery.ajax({
		url: form.attr('action') || "",
		type: form.attr('type') || "get",
		dataType: 'application/json',
		data: data
	}).always(callback);
};

jQuery(document).ready(function($) {
	// Settings page
	let toggleAccordionState = function() {
		$('#ti-settings .accordion-item .accordion-button').addClass('disabled');
		$('#ti-settings .accordion-item .accordion-button:not(.done):first').removeClass('disabled');

		setPreviewIframe();
	};

	// switch checkbox
	$(document).on('change', '.form-switch input[type=checkbox]', function(event) {
		let checkbox = $(this);
		let label = checkbox.next();

		label.html(checkbox.prop('checked') ? label.data('on-text') : label.data('off-text'));
	});

	$('.form-switch input[type=checkbox]').trigger('change');

	// next button click
	$(document).on('click', '#ti-settings .btn-next', function(event) {
		event.preventDefault();

		let btn = $(this);
		btn.blur();

		let accordion = btn.closest('.accordion-item');
		let form = accordion.find('form');

		btn.addClass('btn-loading');

		form.one('submit-success', (event, success) => {
			btn.removeClass('btn-loading');

			if(success)
			{
				accordion.find('.accordion-button').addClass('done');

				if(!btn.hasClass('btn-finished'))
				{
					accordion.next().find('.accordion-button').trigger('click');

					toggleAccordionState();
				}

				if(btn.attr('href') != '#')
				{
					btn.addClass('btn-loading');
					window.location = btn.attr('href');
				}
			}
		}).submit();
	});

	// test review link
	$(document).on('click', '.btn-test-review-link', function(event) {
		event.preventDefault();

		let btn = $(this);
		btn.blur();

		let url = $('#ti-platform-url input[name=platform-url]').val().trim();
		window.open(url, '_blank');
	});

	// validate/submit platform-url
	$(document).on('submit', '#ti-platform-url', function(event) {
		event.preventDefault();

		let form = $(this);
		let input = form.find('input[name=platform-url]');
		let url = input.val().trim();

		form.find('.alert-danger').hide();
		input.removeClass('is-invalid');

		if(url == "" || !/(?:https?):\/\/(\w+:?\w*)?(\S+)(:\d+)?(\/|\/([\w#!:.?+=&%!\-\/]))?/.test(url))
		{
			form.find('.alert-url-invalid').fadeIn();
			input.addClass('is-invalid').focus();

			return form.trigger('submit-success', false);
		}

		form.ajaxSubmit(() => form.trigger('submit-success', true));
	});

	// submit trigger
	$(document).on('submit', '#ti-trigger', function(event) {
		event.preventDefault();

		let form = $(this);
		form.ajaxSubmit(() => form.trigger('submit-success', true));
	});

	// validate/submit email settings
	let getEmailContent = () => {
		let text = "";

		if($('#wp-email-text-wrap').hasClass('tmce-active'))
		{
			text = tinyMCE.get('email-text').getContent().trim();
		}

		if(!text)
		{
			text = $('#email-text').val().trim();
		}

		return text;
	};

	$(document).on('submit', '#ti-email-settings', function(event) {
		event.preventDefault();

		let form = $(this);

		form.find('.alert-danger').hide();
		form.find('input, textarea').removeClass('is-invalid');

		// check fields
		[
			'input[name=email-sender-email]',
			'textarea[name=email-footer-text]',
			'input[name=email-sender]',
			'input[name=email-subject]',
			'input[name=email-button-title]'
		].forEach(selector => {
			let element = form.find(selector);
			if(element.val().trim() == "")
			{
				element.addClass('is-invalid');
			}
		});

		if(form.find('input.is-invalid, textarea.is-invalid').length || getEmailContent == "")
		{
			// scroll page to top
			jQuery(window).scrollTop(0);

			form.find('.alert-empty').fadeIn();

			return form.trigger('submit-success', false);
		}

		// check email
		let email = form.find('input[name=email-sender-email]').val().trim();
		if(!/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/.test(email))
		{
			// scroll page to top
			jQuery(window).scrollTop(0);

			form.find('.alert-email-invalid').fadeIn();
			form.find('input[name=email-sender-email]').addClass('is-invalid').focus();

			return form.trigger('submit-success', false);
		}

		form.ajaxSubmit(() => form.trigger('submit-success', true), { 'email-text': getEmailContent() });
	});

	// sender email warning text
	let toggleSenderEmailWarning = function() {
		let input = $('#ti-email-settings input[name=email-sender-email]');
		let email = input.val().trim().toLowerCase();

		if(location.hostname.indexOf(email.split('@')[1] || "") == -1)
		{
			input.addClass('is-invalid').next().show();
		}
		else
		{
			input.removeClass('is-invalid').next().hide();
		}
	};
	toggleSenderEmailWarning();
	$(document).on('input', '#ti-email-settings input[name=email-sender-email]', toggleSenderEmailWarning);

	// email preview
	let decodeHtml = (html) => {
		var txt = document.createElement("textarea");
		txt.innerHTML = html;
		return txt.value;
	};

	let setPreviewIframe = () => {
		let iframe = $('#ti-email-preview-iframe');

		if(!iframe.length)
		{
			return false;
		}

		let button_title = $('#ti-email-settings input[name=email-button-title]').val().trim();
		let button_link = $('#ti-platform-url input[name=platform-url]').val().trim();
		let html = decodeHtml($('#ti-email-preview-content').html()).replace('{{unsubscribe_url}}', '#');
		let iframe_inner = iframe.contents().find('html');

		iframe_inner.html(html);

		let text = getEmailContent().replace('{{button}}', '<table border="0" cellpadding="0" cellspacing="0" width="100%"><tr><td align="left"><a rel="noopener" target="_blank" href="'+ button_link +'" style="background-color: #2AA8D7; font-size: 18px; font-family: Helvetica, Arial, sans-serif; font-weight: bold; text-decoration: none; padding: 14px 20px; color: #ffffff; border-radius: 5px; display: inline-block; mso-padding-alt: 0;"><span style="mso-text-raise: 15pt;">'+ button_title +'</span></a></td></tr></table>');
		let footer_text = $('#ti-email-settings textarea[name=email-footer-text]').val().trim().replace("\n", '<br />').replace('<a>', '<a style="font-size: inherit; font-family: inherit; color: inherit; text-decoration: underline">');

		iframe_inner.find('#email-content').html(text);
		iframe_inner.find('#email-footer-content').html(footer_text);
		iframe.css('height', iframe_inner.find('table.main').height() + 80);

		// force light mode
		iframe_inner.find('.content-table, .header-bg').css('background-color', '#fff');
		iframe_inner.find('.lightLogo').css('display', 'block');
		iframe_inner.find('.darkLogo').hide();
	};

	$(document).on('click', '#ti-email-preview-tab', () => setTimeout(setPreviewIframe, 200));
	$(document).on('change', '#ti-email-settings input[name=email-button-title]', setPreviewIframe);
	$(document).on('change', '#ti-email-settings textarea[name=email-footer-text]', setPreviewIframe);

	// test email
	$(document).on('click', '.btn-send-test-email', function(event) {
		event.preventDefault();

		let btn = $(this);
		btn.blur();

		let form = $('#ti-email-settings');
		let data = {
			command: 'test-email',
			email: $('#ti-test-email-input').val().trim(),
			'email-text': getEmailContent(),
			'email-footer-text': form.find('textarea[name=email-footer-text]').val().trim(),
			'email-sender': form.find('input[name=email-sender]').val().trim(),
			'email-sender-email': form.find('input[name=email-sender-email]').val().trim(),
			'email-subject': form.find('input[name=email-subject]').val().trim(),
			'email-button-title': form.find('input[name=email-button-title]').val().trim(),
			'platform-url': $('#ti-platform-url input[name=platform-url]').val().trim()
		};

		$('.alert-test-email').hide();

		// check empty field
		for(let key in data) {
			if(data[key] == "" && key != 'email')
			{
				return $('.alert-test-email.alert-empty-2').fadeIn();
			}
		}

		// check email
		$('#ti-test-email-input').removeClass('is-invalid');
		if(data.email == "" || !/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/.test(data.email))
		{
			$('#ti-test-email-input').addClass('is-invalid').focus();

			return $('.alert-test-email.alert-email-invalid-2').fadeIn();
		}

		btn.addClass('btn-loading');

		$.ajax({
			type: 'post',
			dataType: 'application/json',
			data: data
		}).always(() => {
			btn.removeClass('btn-loading');
			$('.alert-test-email.alert-success').fadeIn();

			setTimeout(() => $('.alert-test-email.alert-success').fadeOut(), 5000);
		});
	});

	// toggle campaign
	$(document).on('change', '#ti-campaign-activate-checkbox', function(event) {
		event.preventDefault();

		let input = $(this);
		input.blur();

		input.css('pointer-events', 'none');

		$.ajax({
			type: 'post',
			dataType: 'application/json',
			data: { command: 'toggle-campaign' }
		}).always(() => {
			input.css('pointer-events', '');
		});
	});

	toggleAccordionState();

	// copy to clipboard
	$(document).on('click', '.btn-copy2clipboard', function(event) {
		event.preventDefault();

		let btn = $(this);
		btn.blur();

		let obj = $(btn.attr('href'));
		let text = decodeHtml(obj.html() ? obj.html() : obj.val());

		if(!navigator.clipboard)
		{
			//fallback
			var textArea = document.createElement("textarea");
			textArea.value = text;
			textArea.style.position = "fixed"; //avoid scrolling to bottom
			document.body.appendChild(textArea);
			textArea.focus();
			textArea.select();

			try {
				var successful = document.execCommand('copy');
			} catch (err) { }

			document.body.removeChild(textArea);
			return;
		}

		navigator.clipboard.writeText(text);
	});

	// loading on click
	$(document).on('click', '.btn-loading-on-click', function() {
		let btn = $(this);

		btn.addClass('btn-loading').blur();
	});
});