<?php
/*
Plugin Name: Customer Reviews Collector for WooCommerce
Plugin URI: https://wordpress.org/plugins/customer-reviews-collector-for-woocommerce/
Description: Collect reviews on Google, Facebook, Yelp, Trustindex and other platforms automatically, with the help of our system.
Tags: collect, Woocommerce reviews, customer reviews, Google reviews, review plugin
Version: 1.3
Author: Trustindex.io <support@trustindex.io>
Author URI: https://www.trustindex.io/
Contributors: trustindex
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: customer-reviews-collector-for-woocommerce
Domain Path: /languages
Donate link: https://www.trustindex.io/prices/
*/
/*
You should have received a copy of the GNU General Public License
along with Review widget addon for Divi. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
*/
/*
Copyright 2019 Trustindex Kft (email: support@trustindex.io)
*/
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
require_once plugin_dir_path( __FILE__ ) . 'trustindex-collector-plugin.class.php';
$trustindex_collector = new TrustindexCollectorPlugin(__FILE__, "1.3");
register_activation_hook(__FILE__, [ $trustindex_collector, 'activate' ]);
register_deactivation_hook(__FILE__, [ $trustindex_collector, 'deactivate' ]);
add_action('plugins_loaded', [ $trustindex_collector, 'loadI18N' ]);
add_action('woocommerce_order_status_changed', function($id) {
global $trustindex_collector;
global $wpdb;
$order = new WC_Order($id);
$trigger_event = str_replace('wc-', '', get_option($trustindex_collector->get_option_name('trigger-event'), $trustindex_collector->get_default_settings()['trigger-event']));
if($trustindex_collector->is_campaign_active() && $order->has_status($trigger_event))
{
$order_data = $order->get_data();
$email = strtolower($order_data['billing']['email']);
$customer_full_name = trim($order_data['billing']['first_name'] .' '. $order_data['billing']['last_name']);
if($email && !$trustindex_collector->is_email_unsubscribed($email))
{
$trigger_delay = intval(get_option($trustindex_collector->get_option_name('trigger-delay'), $trustindex_collector->get_default_settings()['trigger-delay']));
$timestamp = time() + ($trigger_delay * 86400);
if(!$trigger_delay)
{
$trustindex_collector->sendMail($email, [ 'customer_full_name' => $customer_full_name ]);
$trustindex_collector->register_schedule_sent($email, $id, null, $customer_full_name);
}
else
{
$wpdb->insert($trustindex_collector->get_tablename('schedule_list'), [
'email' => $email,
'name' => $customer_full_name,
'order_id' => $id,
'timestamp' => $timestamp,
'created_at' => date('Y-m-d H:i:s')
]);
}
}
}
});
add_action('init', function() {
global $trustindex_collector;
if(!isset($trustindex_collector) || is_null($trustindex_collector))
{
if(!class_exists('TrustindexCollectorPlugin'))
{
require_once plugin_dir_path( __FILE__ ) . 'trustindex-collector-plugin.class.php';
}
$trustindex_collector = new TrustindexCollectorPlugin(__FILE__, "1.3");
}
if(!wp_next_scheduled($trustindex_collector->get_schedule_cronname()))
{
wp_schedule_event(time(), 'hourly', $trustindex_collector->get_schedule_cronname());
}
});
add_action($trustindex_collector->get_schedule_cronname(), function() {
global $trustindex_collector;
global $wpdb;
$schedules = $trustindex_collector->get_pending_schedules();
foreach($schedules as $s)
{
$trustindex_collector->sendMail($s->email);
$trustindex_collector->register_schedule_sent($s->email, $s->order_id, $s->id);
}
});
add_action('init', array($trustindex_collector, 'unsubscribe'));
add_action('admin_menu', [ $trustindex_collector, 'add_setting_menu' ], 10);
add_filter('plugin_action_links', [ $trustindex_collector, 'add_plugin_action_links' ], 10, 2);
add_filter('plugin_row_meta', [ $trustindex_collector, 'add_plugin_meta_links' ], 10, 2);
add_action('init', [ $trustindex_collector, 'output_buffer' ]);
add_action('admin_enqueue_scripts', [ $trustindex_collector, 'add_scripts' ]);
add_filter('script_loader_tag', function($tag, $handle) {
if(strpos($tag, 'trustindex.io/loader.js') !== false && strpos($tag, 'defer async') === false) {
$tag = str_replace(' src', ' defer async src', $tag );
}
return $tag;
}, 10, 2);
add_action('admin_notices', function() {
if(class_exists('Woocommerce'))
{
return;
}
echo '<div class="notice notice-error is-dismissible"><p>'. TrustindexCollectorPlugin::___('WooCommerce is not activated, please activate it to use <strong>%s</strong>!', [ 'Customer Reviews Collector for WooCommerce' ]) .'</p></div>';
});
?>